@@ -20,7 +20,6 @@ class Partner:
         email,
         phone,
         mobile,
-        birthdate_date,
         cooperator_register_number,
         cooperator_end_date,
         coop_agreement_code,
@@ -38,7 +37,6 @@ class Partner:
         self.email = email
         self.phone = phone
         self.mobile = mobile
-        self.birthdate_date = birthdate_date
         self.cooperator_register_number = cooperator_register_number
         self.cooperator_end_date = cooperator_end_date
         self.sponsor_id = sponsor_id
